aboutsummaryrefslogtreecommitdiff
path: root/engines/sword2/speech.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/sword2/speech.cpp')
-rw-r--r--engines/sword2/speech.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/engines/sword2/speech.cpp b/engines/sword2/speech.cpp
index a0ddc333c2..b67f079a83 100644
--- a/engines/sword2/speech.cpp
+++ b/engines/sword2/speech.cpp
@@ -104,16 +104,16 @@ void Logic::locateTalker(int32 *params) {
uint16 scale = obMega.calcScale();
// Calc suitable centre point above the head, based on scaled
// height
// just use 'feet_x' as centre
_textX = obMega.getFeetX();
// Add scaled y-offset to feet_y coord to get top of sprite
_textY = obMega.getFeetY() + (cdt_entry.y * scale) / 256;
} else {
// It's a non-scaling anim - calc suitable centre point above
// the head, based on scaled width
// x-coord + half of width
@@ -185,7 +185,7 @@ void Logic::formText(int32 *params) {
text + 2, _textX, _textY,
textWidth, obSpeech.getPen(),
RDSPR_TRANS | RDSPR_DISPLAYALIGN,
- _vm->_speechFontId, POSITION_AT_CENTRE_OF_BASE);
+ _vm->_speechFontId, POSITION_AT_CENTER_OF_BASE);
_vm->_resman->closeResource(text_res);
@@ -104,16 +104,16 @@ void Logic::locateTalker(int32 *params) {
uint16 scale = obMega.calcScale();
- // Calc suitable centre point above the head, based on scaled
+ // Calc suitable center point above the head, based on scaled
// height
@@ -104,16 +104,16 @@ void Logic::locateTalker(int32 *params) {
// height
- // just use 'feet_x' as centre
+ // just use 'feet_x' as center
_textX = obMega.getFeetX();
// Add scaled y-offset to feet_y coord to get top of sprite
@@ -104,16 +104,16 @@ void Logic::locateTalker(int32 *params) {
_textY = obMega.getFeetY() + (cdt_entry.y * scale) / 256;
} else {
- // It's a non-scaling anim - calc suitable centre point above
+ // It's a non-scaling anim - calc suitable center point above
// the head, based on scaled width
// x-coord + half of width